@@ -200,7 +200,7 @@ void Smb4KNetworkBrowserPart::setupActions()
   // is also needed:
   if ( m_mode == KonqPlugin )
   {
-    TDEAction *unmount =     new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut( CTRL+Key_U ),
+    TDEAction *unmount =     new TDEAction( i18n( "&Unmount" ), "drive-harddisk-unmounted", TDEShortcut( CTRL+Key_U ),
                                         this, TQT_SLOT( slotUnmount() ),
                                         actionCollection(), "konq_umount_action" );
 
