@@ -109,11 +109,11 @@ void Smb4KAuthOptions::slotTDEWalletButtonState( int state )
 {
   if ( state == TQCheckBox::On )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultLoginBox", TQGROUPBOX_OBJECT_NAME_STRING, true )) )->setEnabled( true );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultLoginBox", "TQGroupBox", true )) )->setEnabled( true );
   }
   else if ( state == TQCheckBox::Off )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultLoginBox", TQGROUPBOX_OBJECT_NAME_STRING, true )) )->setEnabled( false );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultLoginBox", "TQGroupBox", true )) )->setEnabled( false );
   }
 }
 
@@ -122,11 +122,11 @@ void Smb4KAuthOptions::slotDefaultAuthButtonState( int state )
 {
   if ( state == TQCheckBox::On )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultAuthWidget", TQWIDGET_OBJECT_NAME_STRING, true )) )->setEnabled( true );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultAuthWidget", "TQWidget", true )) )->setEnabled( true );
   }
   else if ( state == TQCheckBox::Off )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultAuthWidget", TQWIDGET_OBJECT_NAME_STRING, true )) )->setEnabled( false );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "DefaultAuthWidget", "TQWidget", true )) )->setEnabled( false );
   }
 }
 
