@@ -298,13 +298,13 @@ void Smb4KRsyncOptions::slotArchiveToggled( bool on )
 {
   if ( on )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_RecurseIntoDirectories", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveSymlinks", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreservePermissions", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveTimes", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveGroup", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveOwner", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveDevicesAndSpecials", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_RecurseIntoDirectories", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveSymlinks", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreservePermissions", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveTimes", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveGroup", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveOwner", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveDevicesAndSpecials", "TQCheckBox", true )) )->setChecked( on );
   }
 }
 
@@ -313,23 +313,23 @@ void Smb4KRsyncOptions::slotUncheckArchive( bool on )
 {
   if ( !on )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ArchiveMode", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ArchiveMode", "TQCheckBox", true )) )->setChecked( on );
   }
 }
 
 
 void Smb4KRsyncOptions::slotBackupToggled( bool on )
 {
-  static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseBackupDirectory", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setEnabled( on );
+  static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseBackupDirectory", "TQCheckBox", true )) )->setEnabled( on );
   static_cast<KURLRequester *>( TQT_TQWIDGET(child( "kcfg_BackupDirectory", "KURLRequester", true )) )->setEnabled( on );
-  static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseBackupSuffix", TQCHECKBOX_OBJECT_NAME_STRING, true )) )->setEnabled( on );
+  static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseBackupSuffix", "TQCheckBox", true )) )->setEnabled( on );
   static_cast<KLineEdit *>( TQT_TQWIDGET(child( "kcfg_BackupSuffix", "KLineEdit", true )) )->setEnabled( on );
 }
 
 
 void Smb4KRsyncOptions::slotFShortcutToggled( bool on )
 {
-  TQCheckBox *ff_filter = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseFFFilterRule", TQCHECKBOX_OBJECT_NAME_STRING, true )) );
+  TQCheckBox *ff_filter = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseFFFilterRule", "TQCheckBox", true )) );
 
   if ( on && ff_filter->isChecked() )
   {
@@ -340,7 +340,7 @@ void Smb4KRsyncOptions::slotFShortcutToggled( bool on )
 
 void Smb4KRsyncOptions::slotFFShortcutToggled( bool on )
 {
-  TQCheckBox *f_filter = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseFFilterRule", TQCHECKBOX_OBJECT_NAME_STRING, true )) );
+  TQCheckBox *f_filter = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseFFilterRule", "TQCheckBox", true )) );
 
   if ( on && f_filter->isChecked() )
   {
