@@ -29,12 +29,12 @@
 #include <tqstringlist.h>
 
 // KDE includes
-#include <kdeversion.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeversion.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kurl.h>
 #include <krun.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kpassivepopup.h>
 #include <kdebug.h>
 #include <kstaticdeleter.h>
@@ -47,13 +47,13 @@
 #include "smb4kcore.h"
 #include "smb4kdefs.h"
 #include "smb4kerror.h"
-#include "smb4kglobal.h"
+#include "smb4tdeglobal.h"
 #include "smb4knetworkitems.h"
 #include "smb4kshare.h"
 #include "smb4ksambaoptionshandler.h"
 #include "smb4ksettings.h"
 
-using namespace Smb4KGlobal;
+using namespace Smb4TDEGlobal;
 
 Smb4KCore *Smb4KCore::m_self = 0;
 static KStaticDeleter<Smb4KCore> staticSmb4KCoreDeleter;
@@ -241,11 +241,11 @@ void Smb4KCore::open( Smb4KShare *share, int openWith )
     return;
   }
 
-#if KDE_VERSION_MAJOR == 3 && KDE_VERSION_MINOR <= 3 && KDE_VERSION_RELEASE <= 92
+#if TDE_VERSION_MAJOR == 3 && TDE_VERSION_MINOR <= 3 && TDE_VERSION_RELEASE <= 92
 
   if ( TQString::compare( share->filesystem(), "cifs" ) == 0 )
   {
-    if( KMessageBox::warningContinueCancel( (TQWidget *)this, i18n( "Up to KDE 3.3.x, KIO and Konqueror cannot handle CIFS shares. Konqueror will hang if you try to access it.\nDo you want to continue?" ) ) == KMessageBox::Cancel )
+    if( KMessageBox::warningContinueCancel( (TQWidget *)this, i18n( "Up to KDE 3.3.x, TDEIO and Konqueror cannot handle CIFS shares. Konqueror will hang if you try to access it.\nDo you want to continue?" ) ) == KMessageBox::Cancel )
     {
       return;
     }
