@@ -62,7 +62,7 @@ class Smb4KAuthInfo;
 
 class Smb4KPasswordHandler : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
