@@ -50,7 +50,7 @@ class Smb4KPreviewItem;
 
 class Smb4KPreviewer : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
