@@ -54,7 +54,7 @@ class Smb4KPrintInfo;
 
 class Smb4KPrint : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
