@@ -46,7 +46,7 @@ class Smb4KShareItem;
 
 class Smb4KCustomOptionsDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
