@@ -50,7 +50,7 @@ class Smb4KShareItem;
 
 class Smb4KPrintDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
