@@ -145,7 +145,7 @@ void Smb4KSynchronizationDialog::slotUser1()
   destination->lineEdit()->setReadOnly( true );
   destination->button()->setEnabled( false );
 
-  TQWidget *transfer_widget = static_cast<TQWidget *>( TQT_TQWIDGET(child( "TransferInfoWidget", TQWIDGET_OBJECT_NAME_STRING, true )) );
+  TQWidget *transfer_widget = static_cast<TQWidget *>( TQT_TQWIDGET(child( "TransferInfoWidget", "TQWidget", true )) );
   transfer_widget->setEnabled( true );
 
   enableButton( User1, false );
@@ -187,8 +187,8 @@ void Smb4KSynchronizationDialog::slotProgress( const Smb4KSynchronizationInfo &i
   KLineEdit *progress =   static_cast<KLineEdit *>( TQT_TQWIDGET(child( "ProgressInfo", "KLineEdit", true )) );
   KProgress *individual = static_cast<KProgress *>( TQT_TQWIDGET(child( "IndividualProgress", "KProgress", true )) );
   KProgress *total =      static_cast<KProgress *>( TQT_TQWIDGET(child( "TotalProgress", "KProgress", true )) );
-  TQLabel *transferred =   static_cast<TQLabel *>( TQT_TQWIDGET(child( "FilesTransferred", TQLABEL_OBJECT_NAME_STRING, true )) );
-  TQLabel *rate =          static_cast<TQLabel *>( TQT_TQWIDGET(child( "TransferRate", TQLABEL_OBJECT_NAME_STRING, true )) );
+  TQLabel *transferred =   static_cast<TQLabel *>( TQT_TQWIDGET(child( "FilesTransferred", "TQLabel", true )) );
+  TQLabel *rate =          static_cast<TQLabel *>( TQT_TQWIDGET(child( "TransferRate", "TQLabel", true )) );
 
   if ( !info.text().isEmpty() )
   {
