@@ -48,7 +48,7 @@ class Smb4KSynchronizationInfo;
 
 class Smb4KSynchronizationDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
