@@ -322,7 +322,7 @@ void Smb4KSharesIconViewToolTip::update()
   }
   else
   {
-    TQLabel *free_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "FreeLabel", TQLABEL_OBJECT_NAME_STRING )) );
+    TQLabel *free_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "FreeLabel", "TQLabel" )) );
 
     if ( free_label )
     {
@@ -337,7 +337,7 @@ void Smb4KSharesIconViewToolTip::update()
       m_free = NULL;
     }
 
-    TQLabel *used_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "UsedLabel", TQLABEL_OBJECT_NAME_STRING )) );
+    TQLabel *used_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "UsedLabel", "TQLabel" )) );
 
     if ( used_label )
     {
@@ -352,7 +352,7 @@ void Smb4KSharesIconViewToolTip::update()
       m_used = NULL;
     }
 
-    TQLabel *total_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "TotalLabel", TQLABEL_OBJECT_NAME_STRING )) );
+    TQLabel *total_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "TotalLabel", "TQLabel" )) );
 
     if ( total_label )
     {
@@ -367,7 +367,7 @@ void Smb4KSharesIconViewToolTip::update()
       m_total = NULL;
     }
 
-    TQLabel *usage_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "UsageLabel", TQLABEL_OBJECT_NAME_STRING )) );
+    TQLabel *usage_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "UsageLabel", "TQLabel" )) );
 
     if ( usage_label )
     {
