@@ -155,7 +155,7 @@ void Smb4KSharesListView::contentsDropEvent( TQDropEvent *e )
   {
     if ( dest.equals( *it, true ) )
     {
-      if ( e->source() == this || TQT_BASE_OBJECT(e->source()->parent()) == TQT_BASE_OBJECT(this) )
+      if ( e->source() == this || e->source()->parent() == this )
       {
         e->ignore();
 
