@@ -77,7 +77,7 @@ Smb4KApp::Smb4KApp( TQWidget *parent, const char *name )
 
   // Setup all things that need to be done *after* createGUI()
   // was run:
-  TQPopupMenu *settings = static_cast<TQPopupMenu *>( TQT_TQWIDGET(child( "settings", TQPOPUPMENU_OBJECT_NAME_STRING, true )) );
+  TQPopupMenu *settings = static_cast<TQPopupMenu *>( TQT_TQWIDGET(child( "settings", "TQPopupMenu", true )) );
 
   if ( settings )
   {
